Function ax_open

#[no_mangle]
pub unsafe extern "C" fn ax_open(
    filename: *const c_char,
    flags: c_int,
    mode: mode_t,
) -> c_int
Open a file by filename and insert it into the file descriptor table.

Return its index in the file table (fd). Return EMFILE if it already has the maximum number of files open.